@@ -2,10 +2,19 @@
 #define GNOME_RADIO_INFO_H 1
 
 #include <glib.h>
+#include <gtk/gtk.h>
 
 typedef struct _LocationInfo LocationInfo;
 typedef struct _RadioInfo RadioInfo;
 typedef struct _StreamInfo StreamInfo;
+typedef struct _RadioWindow RadioWindow;
+
+struct _RadioWindow {
+	GtkWidget *window;
+	gchar *window_title;
+	gchar *text;
+	gchar *uri;
+};
 
 struct _LocationInfo {
 	double *lat;
