@@ -129,8 +129,8 @@ create_radio_marker (void)
 	return radio_marker;
 }
 
-double lat = 40.7265342;
-double lon = -74.0054459;
+double lat = 34.1376417;
+double lon = -118.1507543;
 
 typedef struct
 {
@@ -187,9 +187,8 @@ main (gint argc, gchar **argv)
 	callback_data.radio_marker = CHAMPLAIN_MARKER (radio_marker);
 	/* Create the radio player */
 	player = gst_player_new (NULL, gst_player_g_main_context_signal_dispatcher_new(NULL));
-
 	/* gnome_radio_file_loader (radioinfo, "gnome-radio.xml"); */
-	gst_player_set_uri (GST_PLAYER (player), "http://fm939.wnyc.org/wnycfm");
+	gst_player_set_uri (GST_PLAYER (player), "http://live.scpr.org/kpcclive/");
 	gst_player_stop (GST_PLAYER (player));
 	gst_player_play(GST_PLAYER (player));
 	g_timeout_add (1000, (GSourceFunc) gps_callback, &callback_data);
